==> task-serdes-yaml-22.0.4-sources.jar: akka/serialization/jackson/JacksonYamlSerializer.scala <==
package akka.serialization.jackson

import ai.digital.deploy.task.serdes.TaskAkkaSerializer
import ai.digital.deploy.task.serdes.yaml.DeployStringQuotingChecker
import akka.actor.ExtendedActorSystem
import akka.event.Logging
import com.fasterxml.jackson.databind.SerializationFeature
import com.fasterxml.jackson.dataformat.yaml.{YAMLFactory, YAMLGenerator}
import org.apache.commons.io.FileUtils

import java.io.File

final class JacksonYamlSerializer(system: ExtendedActorSystem, bindingName: String)
  extends JacksonSerializer(
    system,
    bindingName: String,
    JacksonObjectMapperProvider(system).getOrCreate(
      bindingName,
      Some(
        new YAMLFactory()
          .disable(YAMLGenerator.Feature.USE_NATIVE_TYPE_ID)
          .disable(YAMLGenerator.Feature.USE_NATIVE_OBJECT_ID)
          .disable(YAMLGenerator.Feature.WRITE_DOC_START_MARKER)
          .enable(YAMLGenerator.Feature.MINIMIZE_QUOTES)
          .rebuild()
          .stringQuotingChecker(DeployStringQuotingChecker)
          .build()
      )
    )
      .disable(SerializationFeature.FAIL_ON_EMPTY_BEANS)
      .deactivateDefaultTyping()
  ) with TaskAkkaSerializer {

  private val log = Logging.withMarker(system, classOf[JacksonSerializer])
  private val conf = JacksonObjectMapperProvider.configForBinding(bindingName, system.settings.config)
  private val isDebugEnabled = conf.getBoolean("verbose-debug-logging") && log.isDebugEnabled

  // TODO recheck ENG-7355
  private val serializationBindingsCheckedOkField = classOf[JacksonSerializer].getDeclaredField("serializationBindingsCheckedOk")
  serializationBindingsCheckedOkField.setAccessible(true)
  serializationBindingsCheckedOkField.setBoolean(this, true)
  serializationBindingsCheckedOkField.setAccessible(false)

  override def initExternalWorker(conf: TaskAkkaSerializer.Conf): Unit = {}

  override def toBinary(obj: AnyRef): Array[Byte] = {
    val bytes = super.toBinary(obj)
    if (isDebugEnabled) {
      log.debug("Serialization of {} to {}", obj.getClass, new String(bytes))
    }
    bytes
  }

  override def fromBinary(bytes: Array[Byte], manifest: String): AnyRef = {
    if (log.isDebugEnabled) {
      log.debug("Deserialization of {} to {}", manifest, new String(bytes))
    }
    super.fromBinary(bytes, manifest)
  }
}

==> task-serdes-yaml-23.3.0-rc.4-sources.jar: akka/serialization/jackson/JacksonYamlSerializer.scala <==
package akka.serialization.jackson

import ai.digital.deploy.task.serdes.TaskAkkaSerializer
import ai.digital.deploy.task.serdes.yaml.DeployStringQuotingChecker
import akka.actor.ExtendedActorSystem
import akka.event.Logging
import com.fasterxml.jackson.databind.SerializationFeature
import com.fasterxml.jackson.dataformat.yaml.{YAMLFactory, YAMLGenerator}

final class JacksonYamlSerializer(system: ExtendedActorSystem, bindingName: String)
  extends JacksonSerializer(
    system,
    bindingName: String,
    JacksonObjectMapperProvider(system).getOrCreate(
      bindingName,
      Some(
        new YAMLFactory()
          .disable(YAMLGenerator.Feature.USE_NATIVE_TYPE_ID)
          .disable(YAMLGenerator.Feature.USE_NATIVE_OBJECT_ID)
          .disable(YAMLGenerator.Feature.WRITE_DOC_START_MARKER)
          .enable(YAMLGenerator.Feature.MINIMIZE_QUOTES)
          .rebuild()
          .stringQuotingChecker(DeployStringQuotingChecker)
          .build()
      )
    )
      .disable(SerializationFeature.FAIL_ON_EMPTY_BEANS)
      .deactivateDefaultTyping()
  ) with TaskAkkaSerializer {

  private val log = Logging.withMarker(system, classOf[JacksonSerializer])
  private val conf = JacksonObjectMapperProvider.configForBinding(bindingName, system.settings.config)
  private val isDebugEnabled = conf.getBoolean("verbose-debug-logging") && log.isDebugEnabled

  // TODO recheck ENG-7355
  private val serializationBindingsCheckedOkField = classOf[JacksonSerializer].getDeclaredField("serializationBindingsCheckedOk")
  serializationBindingsCheckedOkField.setAccessible(true)
  serializationBindingsCheckedOkField.setBoolean(this, true)
  serializationBindingsCheckedOkField.setAccessible(false)

  override def initExternalWorker(conf: TaskAkkaSerializer.Conf, createWorkDir: Boolean = true): Unit = {}

  override def toBinary(obj: AnyRef): Array[Byte] = {
    val bytes = super.toBinary(obj)
    if (isDebugEnabled) {
      log.debug("Serialization of {} to {}", obj.getClass, new String(bytes))
    }
    bytes
  }

  override def fromBinary(bytes: Array[Byte], manifest: String): AnyRef = {
    if (log.isDebugEnabled) {
      log.debug("Deserialization of {} to {}", manifest, new String(bytes))
    }
    super.fromBinary(bytes, manifest)
  }
}
